@@ -20,7 +20,7 @@ class login:
             text=''
         else:
             pass
-        print(akey)
+        print(text+akey)
     def auth(auth_id):
         if auth_id=='':
             print('Please Enter auth_id')
@@ -45,6 +45,7 @@ class login:
                     pass
                 elif info+'=block' in r.text:
                     print('This Account Is Blocked')
+                    sys.exit()
             else:
                 print('Unexpected Error!')
                 sys.exit()
